diff mbox series

[10/14] hw/mips/fuloong2e: Fix typo in Fuloong machine name

Message ID 20200526104726.11273-11-f4bug@amsat.org
State New
Headers show
Series hw/mips: patch queue for 2020-05-26 | expand

Commit Message

Philippe Mathieu-Daudé May 26, 2020, 10:47 a.m. UTC
We always miswrote the Fuloong machine... Fix its name.
Add an machine alias to the previous name for backward
compatibility.

Suggested-by: Aleksandar Markovic <amarkovic@wavecomp.com>
Message-id: <20200510210128.18343-5-f4bug@amsat.org>
Signed-off-by: Philippe Mathieu-Daudé <f4bug@amsat.org>
---
 docs/system/deprecated.rst               |  5 +++
 docs/system/target-mips.rst              |  2 +-
 default-configs/mips64el-softmmu.mak     |  2 +-
 hw/isa/vt82c686.c                        |  2 +-
 hw/mips/{mips_fulong2e.c => fuloong2e.c} | 41 ++++++++++++------------
 hw/pci-host/bonito.c                     |  8 ++---
 tests/qtest/endianness-test.c            |  2 +-
 MAINTAINERS                              |  4 +--
 hw/mips/Kconfig                          |  2 +-
 hw/mips/Makefile.objs                    |  2 +-
 10 files changed, 38 insertions(+), 32 deletions(-)
 rename hw/mips/{mips_fulong2e.c => fuloong2e.c} (91%)

Comments

Aleksandar Markovic May 26, 2020, 10:57 a.m. UTC | #1
уто, 26. мај 2020. у 12:47 Philippe Mathieu-Daudé <f4bug@amsat.org> је
написао/ла:
>
> We always miswrote the Fuloong machine... Fix its name.
> Add an machine alias to the previous name for backward
> compatibility.
>
> Suggested-by: Aleksandar Markovic <amarkovic@wavecomp.com>
> Message-id: <20200510210128.18343-5-f4bug@amsat.org>
> Signed-off-by: Philippe Mathieu-Daudé <f4bug@amsat.org>
> ---


Reviewed-by: Aleksandar Markovic <aleksandar.qemu.devel@gmail.com>
>  docs/system/deprecated.rst               |  5 +++
>  docs/system/target-mips.rst              |  2 +-
>  default-configs/mips64el-softmmu.mak     |  2 +-
>  hw/isa/vt82c686.c                        |  2 +-
>  hw/mips/{mips_fulong2e.c => fuloong2e.c} | 41 ++++++++++++------------
>  hw/pci-host/bonito.c                     |  8 ++---
>  tests/qtest/endianness-test.c            |  2 +-
>  MAINTAINERS                              |  4 +--
>  hw/mips/Kconfig                          |  2 +-
>  hw/mips/Makefile.objs                    |  2 +-
>  10 files changed, 38 insertions(+), 32 deletions(-)
>  rename hw/mips/{mips_fulong2e.c => fuloong2e.c} (91%)
>
> diff --git a/docs/system/deprecated.rst b/docs/system/deprecated.rst
> index 3142fac386..f0061f94aa 100644
> --- a/docs/system/deprecated.rst
> +++ b/docs/system/deprecated.rst
> @@ -368,6 +368,11 @@ mips ``r4k`` platform (since 5.0)
>  This machine type is very old and unmaintained. Users should use the ``malta``
>  machine type instead.
>
> +mips ``fulong2e`` machine (since 5.1)
> +'''''''''''''''''''''''''''''''''''''
> +
> +This machine has been renamed ``fuloong2e``.
> +
>  ``pc-1.0``, ``pc-1.1``, ``pc-1.2`` and ``pc-1.3`` (since 5.0)
>  '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
>
> diff --git a/docs/system/target-mips.rst b/docs/system/target-mips.rst
> index 2736fd0509..cd2a931edf 100644
> --- a/docs/system/target-mips.rst
> +++ b/docs/system/target-mips.rst
> @@ -74,7 +74,7 @@ The MIPS Magnum R4000 emulation supports:
>
>  -  G364 framebuffer
>
> -The Fulong 2E emulation supports:
> +The Fuloong 2E emulation supports:
>
>  -  Loongson 2E CPU
>
> diff --git a/default-configs/mips64el-softmmu.mak b/default-configs/mips64el-softmmu.mak
> index 8b0c9b1e15..9f8a3ef156 100644
> --- a/default-configs/mips64el-softmmu.mak
> +++ b/default-configs/mips64el-softmmu.mak
> @@ -2,7 +2,7 @@
>
>  include mips-softmmu-common.mak
>  CONFIG_IDE_VIA=y
> -CONFIG_FULONG=y
> +CONFIG_FULOONG=y
>  CONFIG_ATI_VGA=y
>  CONFIG_RTL8139_PCI=y
>  CONFIG_JAZZ=y
> diff --git a/hw/isa/vt82c686.c b/hw/isa/vt82c686.c
> index d9b51fce8d..fac4e56b7d 100644
> --- a/hw/isa/vt82c686.c
> +++ b/hw/isa/vt82c686.c
> @@ -503,7 +503,7 @@ static void via_class_init(ObjectClass *klass, void *data)
>      dc->vmsd = &vmstate_via;
>      /*
>       * Reason: part of VIA VT82C686 southbridge, needs to be wired up,
> -     * e.g. by mips_fulong2e_init()
> +     * e.g. by mips_fuloong2e_init()
>       */
>      dc->user_creatable = false;
>  }
> diff --git a/hw/mips/mips_fulong2e.c b/hw/mips/fuloong2e.c
> similarity index 91%
> rename from hw/mips/mips_fulong2e.c
> rename to hw/mips/fuloong2e.c
> index 6996f5e3d1..f583c44b79 100644
> --- a/hw/mips/mips_fulong2e.c
> +++ b/hw/mips/fuloong2e.c
> @@ -1,5 +1,5 @@
>  /*
> - * QEMU fulong 2e mini pc support
> + * QEMU fuloong 2e mini pc support
>   *
>   * Copyright (c) 2008 yajin (yajin@vm-kernel.org)
>   * Copyright (c) 2009 chenming (chenming@rdc.faw.com.cn)
> @@ -11,8 +11,8 @@
>   */
>
>  /*
> - * Fulong 2e mini pc is based on ICT/ST Loongson 2e CPU (MIPS III like, 800MHz)
> - * http://www.linux-mips.org/wiki/Fulong
> + * Fuloong 2e mini pc is based on ICT/ST Loongson 2e CPU (MIPS III like, 800MHz)
> + * https://www.linux-mips.org/wiki/Fuloong_2E
>   *
>   * Loongson 2e user manual:
>   * http://www.loongsondeveloper.com/doc/Loongson2EUserGuide.pdf
> @@ -45,13 +45,13 @@
>  #include "sysemu/reset.h"
>  #include "qemu/error-report.h"
>
> -#define DEBUG_FULONG2E_INIT
> +#define DEBUG_FULOONG2E_INIT
>
>  #define ENVP_ADDR               0x80002000l
>  #define ENVP_NB_ENTRIES         16
>  #define ENVP_ENTRY_SIZE         256
>
> -/* fulong 2e has a 512k flash: Winbond W39L040AP70Z */
> +/* Fuloong 2e has a 512k flash: Winbond W39L040AP70Z */
>  #define BIOS_SIZE               (512 * KiB)
>  #define MAX_IDE_BUS             2
>
> @@ -68,12 +68,12 @@
>   * 2, use "Bonito2edev" to replace "dir_corresponding_to_your_target_hardware"
>   * in the "Compile Guide".
>   */
> -#define FULONG_BIOSNAME "pmon_fulong2e.bin"
> +#define FULOONG_BIOSNAME "pmon_2e.bin"
>
> -/* PCI SLOT in fulong 2e */
> -#define FULONG2E_VIA_SLOT        5
> -#define FULONG2E_ATI_SLOT        6
> -#define FULONG2E_RTL8139_SLOT    7
> +/* PCI SLOT in Fuloong 2e */
> +#define FULOONG2E_VIA_SLOT        5
> +#define FULOONG2E_ATI_SLOT        6
> +#define FULOONG2E_RTL8139_SLOT    7
>
>  static struct _loaderparams {
>      int ram_size;
> @@ -278,7 +278,7 @@ static void network_init(PCIBus *pci_bus)
>          const char *default_devaddr = NULL;
>
>          if (i == 0 && (!nd->model || strcmp(nd->model, "rtl8139") == 0)) {
> -            /* The fulong board has a RTL8139 card using PCI SLOT 7 */
> +            /* The Fuloong board has a RTL8139 card using PCI SLOT 7 */
>              default_devaddr = "07";
>          }
>
> @@ -286,7 +286,7 @@ static void network_init(PCIBus *pci_bus)
>      }
>  }
>
> -static void mips_fulong2e_init(MachineState *machine)
> +static void mips_fuloong2e_init(MachineState *machine)
>  {
>      const char *kernel_filename = machine->kernel_filename;
>      const char *kernel_cmdline = machine->kernel_cmdline;
> @@ -318,7 +318,7 @@ static void mips_fulong2e_init(MachineState *machine)
>      memory_region_add_subregion(address_space_mem, 0, machine->ram);
>
>      /* Boot ROM */
> -    memory_region_init_rom(bios, NULL, "fulong2e.bios", BIOS_SIZE,
> +    memory_region_init_rom(bios, NULL, "fuloong2e.bios", BIOS_SIZE,
>                             &error_fatal);
>      memory_region_add_subregion(address_space_mem, 0x1fc00000LL, bios);
>
> @@ -336,7 +336,7 @@ static void mips_fulong2e_init(MachineState *machine)
>          write_bootloader(env, memory_region_get_ram_ptr(bios), kernel_entry);
>      } else {
>          if (bios_name == NULL) {
> -                bios_name = FULONG_BIOSNAME;
> +                bios_name = FULOONG_BIOSNAME;
>          }
>          filename = qemu_find_file(QEMU_FILE_TYPE_BIOS, bios_name);
>          if (filename) {
> @@ -362,7 +362,7 @@ static void mips_fulong2e_init(MachineState *machine)
>      pci_bus = bonito_init((qemu_irq *)&(env->irq[2]));
>
>      /* South bridge -> IP5 */
> -    vt82c686b_southbridge_init(pci_bus, FULONG2E_VIA_SLOT, env->irq[5],
> +    vt82c686b_southbridge_init(pci_bus, FULOONG2E_VIA_SLOT, env->irq[5],
>                                 &smbus, &isa_bus);
>
>      /* GPU */
> @@ -383,14 +383,15 @@ static void mips_fulong2e_init(MachineState *machine)
>      network_init(pci_bus);
>  }
>
> -static void mips_fulong2e_machine_init(MachineClass *mc)
> +static void mips_fuloong2e_machine_init(MachineClass *mc)
>  {
> -    mc->desc = "Fulong 2e mini pc";
> -    mc->init = mips_fulong2e_init;
> +    mc->desc = "Fuloong 2e mini pc";
> +    mc->alias = "fulong2e";             /* Incorrect name used up to QEMU 4.2 */
> +    mc->init = mips_fuloong2e_init;
>      mc->block_default_type = IF_IDE;
>      mc->default_cpu_type = MIPS_CPU_TYPE_NAME("Loongson-2E");
>      mc->default_ram_size = 256 * MiB;
> -    mc->default_ram_id = "fulong2e.ram";
> +    mc->default_ram_id = "fuloong2e.ram";
>  }
>
> -DEFINE_MACHINE("fulong2e", mips_fulong2e_machine_init)
> +DEFINE_MACHINE("fuloong2e", mips_fuloong2e_machine_init)
> diff --git a/hw/pci-host/bonito.c b/hw/pci-host/bonito.c
> index d0201ce59e..f9697dcc43 100644
> --- a/hw/pci-host/bonito.c
> +++ b/hw/pci-host/bonito.c
> @@ -11,7 +11,7 @@
>   */
>
>  /*
> - * fulong 2e mini pc has a bonito north bridge.
> + * fuloong 2e mini pc has a bonito north bridge.
>   */
>
>  /*
> @@ -573,11 +573,11 @@ static int pci_bonito_map_irq(PCIDevice *pci_dev, int irq_num)
>      slot = (pci_dev->devfn >> 3);
>
>      switch (slot) {
> -    case 5:   /* FULONG2E_VIA_SLOT, SouthBridge, IDE, USB, ACPI, AC97, MC97 */
> +    case 5:   /* FULOONG2E_VIA_SLOT, SouthBridge, IDE, USB, ACPI, AC97, MC97 */
>          return irq_num % 4 + BONITO_IRQ_BASE;
> -    case 6:   /* FULONG2E_ATI_SLOT, VGA */
> +    case 6:   /* FULOONG2E_ATI_SLOT, VGA */
>          return 4 + BONITO_IRQ_BASE;
> -    case 7:   /* FULONG2E_RTL_SLOT, RTL8139 */
> +    case 7:   /* FULOONG2E_RTL_SLOT, RTL8139 */
>          return 5 + BONITO_IRQ_BASE;
>      case 8 ... 12: /* PCI slot 1 to 4 */
>          return (slot - 8 + irq_num) + 6 + BONITO_IRQ_BASE;
> diff --git a/tests/qtest/endianness-test.c b/tests/qtest/endianness-test.c
> index 2798802c63..cc088ac01a 100644
> --- a/tests/qtest/endianness-test.c
> +++ b/tests/qtest/endianness-test.c
> @@ -33,7 +33,7 @@ static const TestCase test_cases[] = {
>      { "mips64", "pica61", 0x90000000, .bswap = true },
>      { "mips64", "mips", 0x14000000, .bswap = true },
>      { "mips64", "malta", 0x10000000, .bswap = true },
> -    { "mips64el", "fulong2e", 0x1fd00000 },
> +    { "mips64el", "fuloong2e", 0x1fd00000 },
>      { "ppc", "g3beige", 0xfe000000, .bswap = true, .superio = "i82378" },
>      { "ppc", "40p", 0x80000000, .bswap = true },
>      { "ppc", "bamboo", 0xe8000000, .bswap = true, .superio = "i82378" },
> diff --git a/MAINTAINERS b/MAINTAINERS
> index 8f597aae12..8136a0e56c 100644
> --- a/MAINTAINERS
> +++ b/MAINTAINERS
> @@ -1081,13 +1081,13 @@ R: Aleksandar Rikalo <aleksandar.rikalo@rt-rk.com>
>  S: Obsolete
>  F: hw/mips/mips_r4k.c
>
> -Fulong 2E
> +Fuloong 2E
>  M: Huacai Chen <chenhc@lemote.com>
>  M: Philippe Mathieu-Daudé <f4bug@amsat.org>
>  M: Aleksandar Markovic <aleksandar.qemu.devel@gmail.com>
>  R: Jiaxun Yang <jiaxun.yang@flygoat.com>
>  S: Odd Fixes
> -F: hw/mips/mips_fulong2e.c
> +F: hw/mips/fuloong2e.c
>  F: hw/isa/vt82c686.c
>  F: hw/pci-host/bonito.c
>  F: include/hw/isa/vt82c686.h
> diff --git a/hw/mips/Kconfig b/hw/mips/Kconfig
> index 2240504dff..67d39c56a4 100644
> --- a/hw/mips/Kconfig
> +++ b/hw/mips/Kconfig
> @@ -41,7 +41,7 @@ config JAZZ
>      select DS1225Y
>      select JAZZ_LED
>
> -config FULONG
> +config FULOONG
>      bool
>      select PCI_BONITO
>
> diff --git a/hw/mips/Makefile.objs b/hw/mips/Makefile.objs
> index 525809af07..8ab41edc3f 100644
> --- a/hw/mips/Makefile.objs
> +++ b/hw/mips/Makefile.objs
> @@ -3,6 +3,6 @@ obj-$(CONFIG_R4K) += mips_r4k.o
>  obj-$(CONFIG_MALTA) += gt64xxx_pci.o mips_malta.o
>  obj-$(CONFIG_MIPSSIM) += mips_mipssim.o
>  obj-$(CONFIG_JAZZ) += mips_jazz.o
> -obj-$(CONFIG_FULONG) += mips_fulong2e.o
> +obj-$(CONFIG_FULOONG) += fuloong2e.o
>  obj-$(CONFIG_MIPS_CPS) += cps.o
>  obj-$(CONFIG_MIPS_BOSTON) += boston.o
> --
> 2.21.3
>
Peter Krempa May 26, 2020, 11:53 a.m. UTC | #2
On Tue, May 26, 2020 at 12:47:22 +0200, Philippe Mathieu-Daudé wrote:
> We always miswrote the Fuloong machine... Fix its name.
> Add an machine alias to the previous name for backward
> compatibility.
> 
> Suggested-by: Aleksandar Markovic <amarkovic@wavecomp.com>
> Message-id: <20200510210128.18343-5-f4bug@amsat.org>
> Signed-off-by: Philippe Mathieu-Daudé <f4bug@amsat.org>
> ---

[...]

> diff --git a/docs/system/deprecated.rst b/docs/system/deprecated.rst
> index 3142fac386..f0061f94aa 100644
> --- a/docs/system/deprecated.rst
> +++ b/docs/system/deprecated.rst
> @@ -368,6 +368,11 @@ mips ``r4k`` platform (since 5.0)
>  This machine type is very old and unmaintained. Users should use the ``malta``
>  machine type instead.
>  
> +mips ``fulong2e`` machine (since 5.1)
> +'''''''''''''''''''''''''''''''''''''
> +
> +This machine has been renamed ``fuloong2e``.
> +

Libvirt doesn't have any special handling for this machine so this
shouldn't impact us.
Aleksandar Markovic May 26, 2020, 12:37 p.m. UTC | #3
> >
> > +mips ``fulong2e`` machine (since 5.1)
> > +'''''''''''''''''''''''''''''''''''''
> > +
> > +This machine has been renamed ``fuloong2e``.
> > +
>
> Libvirt doesn't have any special handling for this machine so this
> shouldn't impact us.
>

Well, Peter,

I was also wondering libvirt listed as a recipient, and I think it
creates unneeded noise in your group, but Philippe uses some his
system for automatic picking of recipients, and libivrt somehow
appears there during that process. Philippe, either correct that
detail in this particular component of your workflow, or change
entirely your system for recipient choice - the current workflow
creates incredible amount of noise, wasting time of many people.

This happened before in case of deprecating an ancient mips machine,
that absolutely  doesn't have anything to do with linvirt.

In some large companies, there where some analysis on how much is the
cost of sending an e-mail to all people in the company, in terms of
wasting time on reading or just seeing such email. The result was:
such single e-mail costs the company $2000 - in wasted time of its
employees.

Aleksanadar
Philippe Mathieu-Daudé May 26, 2020, 12:47 p.m. UTC | #4
On 5/26/20 2:37 PM, Aleksandar Markovic wrote:
>>>
>>> +mips ``fulong2e`` machine (since 5.1)
>>> +'''''''''''''''''''''''''''''''''''''
>>> +
>>> +This machine has been renamed ``fuloong2e``.
>>> +
>>
>> Libvirt doesn't have any special handling for this machine so this
>> shouldn't impact us.
>>
> 
> Well, Peter,
> 
> I was also wondering libvirt listed as a recipient, and I think it
> creates unneeded noise in your group, but Philippe uses some his
> system for automatic picking of recipients, and libivrt somehow
> appears there during that process. Philippe, either correct that
> detail in this particular component of your workflow, or change
> entirely your system for recipient choice - the current workflow
> creates incredible amount of noise, wasting time of many people.
> 
> This happened before in case of deprecating an ancient mips machine,
> that absolutely  doesn't have anything to do with linvirt.

See commit b02c9bc35a0:

    MAINTAINERS: New section "Incompatible changes", copy libvir-list

    Libvirt developers would like to be copied on patches to qemu-doc
    appendix "Deprecated features".  Do them the favor.

    Signed-off-by: Markus Armbruster <armbru@redhat.com>
    Reviewed-by: Thomas Huth <thuth@redhat.com>
    Reviewed-by: Cornelia Huck <cohuck@redhat.com>
    Reviewed-by: Daniel P. Berrangé <berrange@redhat.com>

What says Peter is as a libvirt maintainer he is fine with this
deprecation, as it doesn't have side effect on libvirt.

Similarly with the previous "ancient mips machine".

> 
> In some large companies, there where some analysis on how much is the
> cost of sending an e-mail to all people in the company, in terms of
> wasting time on reading or just seeing such email. The result was:
> such single e-mail costs the company $2000 - in wasted time of its
> employees.
> 
> Aleksanadar
>
Peter Krempa May 26, 2020, 12:50 p.m. UTC | #5
On Tue, May 26, 2020 at 14:37:41 +0200, Aleksandar Markovic wrote:
> > >
> > > +mips ``fulong2e`` machine (since 5.1)
> > > +'''''''''''''''''''''''''''''''''''''
> > > +
> > > +This machine has been renamed ``fuloong2e``.
> > > +
> >
> > Libvirt doesn't have any special handling for this machine so this
> > shouldn't impact us.
> >
> 
> Well, Peter,
> 
> I was also wondering libvirt listed as a recipient, and I think it
> creates unneeded noise in your group, but Philippe uses some his
> system for automatic picking of recipients, and libivrt somehow
> appears there during that process. Philippe, either correct that
> detail in this particular component of your workflow, or change
> entirely your system for recipient choice - the current workflow
> creates incredible amount of noise, wasting time of many people.

Note that my message above was not a criticism of why we've got it but
more of a review. This review though it just that removing this is okay
and no action needs to be taken. Unfortunately I'm usually not familiar
enough with qemu to do a full review.

> 
> This happened before in case of deprecating an ancient mips machine,
> that absolutely  doesn't have anything to do with linvirt.

In some cases it might seem like that. Specifically for things where
libvirt isn't impacted such as machine type change because we try to
stay machine type agnostic or for something that we don't use.

On the other hand there were plenty cases where we were impacted and
where we do want to know about these deprecations. It's in fact the
primary reason why this was established after an agreement between qemu
and libvirt projects and in fact I was one of those who argued for
adding such a thing.

As I was one of the proponents I feel obliged to always respond to these
notifications as we've more than once encountered something that in the
end impacted libvirt.

Please do keep sending these to libvirt. It's appreciated to know that
something is going to change! In some cases we don't get a notification
(such as in the recent QAPIfication of netdev-add where non-well-formed
string stopped to be accepted by qemu) and then we have to figure out
only after it trickles down to users.
Aleksandar Markovic May 26, 2020, 1:04 p.m. UTC | #6
уто, 26. мај 2020. у 14:50 Peter Krempa <pkrempa@redhat.com> је написао/ла:
>
> On Tue, May 26, 2020 at 14:37:41 +0200, Aleksandar Markovic wrote:
> > > >
> > > > +mips ``fulong2e`` machine (since 5.1)
> > > > +'''''''''''''''''''''''''''''''''''''
> > > > +
> > > > +This machine has been renamed ``fuloong2e``.
> > > > +
> > >
> > > Libvirt doesn't have any special handling for this machine so this
> > > shouldn't impact us.
> > >
> >
> > Well, Peter,
> >
> > I was also wondering libvirt listed as a recipient, and I think it
> > creates unneeded noise in your group, but Philippe uses some his
> > system for automatic picking of recipients, and libivrt somehow
> > appears there during that process. Philippe, either correct that
> > detail in this particular component of your workflow, or change
> > entirely your system for recipient choice - the current workflow
> > creates incredible amount of noise, wasting time of many people.
>
> Note that my message above was not a criticism of why we've got it but
> more of a review. This review though it just that removing this is okay
> and no action needs to be taken. Unfortunately I'm usually not familiar
> enough with qemu to do a full review.
>
> >
> > This happened before in case of deprecating an ancient mips machine,
> > that absolutely  doesn't have anything to do with linvirt.
>
> In some cases it might seem like that. Specifically for things where
> libvirt isn't impacted such as machine type change because we try to
> stay machine type agnostic or for something that we don't use.
>
> On the other hand there were plenty cases where we were impacted and
> where we do want to know about these deprecations. It's in fact the
> primary reason why this was established after an agreement between qemu
> and libvirt projects and in fact I was one of those who argued for
> adding such a thing.
>
> As I was one of the proponents I feel obliged to always respond to these
> notifications as we've more than once encountered something that in the
> end impacted libvirt.
>

Glad to know that you guy have clear division of responsibility between members.

Good to know the background of all this.

Thanks you,
Aleksandar

> Please do keep sending these to libvirt. It's appreciated to know that
> something is going to change! In some cases we don't get a notification
> (such as in the recent QAPIfication of netdev-add where non-well-formed
> string stopped to be accepted by qemu) and then we have to figure out
> only after it trickles down to users.
>
Aleksandar Markovic May 27, 2020, 8:51 a.m. UTC | #7
уто, 26. мај 2020. у 15:04 Aleksandar Markovic
<aleksandar.qemu.devel@gmail.com> је написао/ла:
>
> уто, 26. мај 2020. у 14:50 Peter Krempa <pkrempa@redhat.com> је написао/ла:
> >
> > On Tue, May 26, 2020 at 14:37:41 +0200, Aleksandar Markovic wrote:
> > > > >
> > > > > +mips ``fulong2e`` machine (since 5.1)
> > > > > +'''''''''''''''''''''''''''''''''''''
> > > > > +
> > > > > +This machine has been renamed ``fuloong2e``.
> > > > > +
> > > >
> > > > Libvirt doesn't have any special handling for this machine so this
> > > > shouldn't impact us.
> > > >
> > >
> > > Well, Peter,
> > >
> > > I was also wondering libvirt listed as a recipient, and I think it
> > > creates unneeded noise in your group, but Philippe uses some his
> > > system for automatic picking of recipients, and libivrt somehow
> > > appears there during that process. Philippe, either correct that
> > > detail in this particular component of your workflow, or change
> > > entirely your system for recipient choice - the current workflow
> > > creates incredible amount of noise, wasting time of many people.
> >
> > Note that my message above was not a criticism of why we've got it but
> > more of a review. This review though it just that removing this is okay
> > and no action needs to be taken. Unfortunately I'm usually not familiar
> > enough with qemu to do a full review.
> >
> > >
> > > This happened before in case of deprecating an ancient mips machine,
> > > that absolutely  doesn't have anything to do with linvirt.
> >
> > In some cases it might seem like that. Specifically for things where
> > libvirt isn't impacted such as machine type change because we try to
> > stay machine type agnostic or for something that we don't use.
> >
> > On the other hand there were plenty cases where we were impacted and
> > where we do want to know about these deprecations. It's in fact the
> > primary reason why this was established after an agreement between qemu
> > and libvirt projects and in fact I was one of those who argued for
> > adding such a thing.
> >
> > As I was one of the proponents I feel obliged to always respond to these
> > notifications as we've more than once encountered something that in the
> > end impacted libvirt.
> >

But, Peter Krempa,

I see libvirt-dev listed as a recipient for a patch (from this series)
that changes an e-mail of a colleague of mine. Why would be
libvirt-dev be interested in that? Is libvirt really so sensitive to
the degree that to be afraid that changing an e-mail of a QEMU
contributor would impact libvirt design and/or its interface towards
QEMU? If you wishes that to remain so, I am of course fine with it,
who am I to determine that, but it looks like a severe overkill to me.

Best Regards,
Aleksandar



>
> Glad to know that you guy have clear division of responsibility between members.
>
> Good to know the background of all this.
>
> Thanks you,
> Aleksandar
>
> > Please do keep sending these to libvirt. It's appreciated to know that
> > something is going to change! In some cases we don't get a notification
> > (such as in the recent QAPIfication of netdev-add where non-well-formed
> > string stopped to be accepted by qemu) and then we have to figure out
> > only after it trickles down to users.
> >
Peter Krempa May 27, 2020, 9:05 a.m. UTC | #8
On Wed, May 27, 2020 at 10:51:21 +0200, Aleksandar Markovic wrote:
> уто, 26. мај 2020. у 15:04 Aleksandar Markovic
> <aleksandar.qemu.devel@gmail.com> је написао/ла:
> >
> > уто, 26. мај 2020. у 14:50 Peter Krempa <pkrempa@redhat.com> је написао/ла:
> > >
> > > On Tue, May 26, 2020 at 14:37:41 +0200, Aleksandar Markovic wrote:
> > > > > >
> > > > > > +mips ``fulong2e`` machine (since 5.1)
> > > > > > +'''''''''''''''''''''''''''''''''''''
> > > > > > +
> > > > > > +This machine has been renamed ``fuloong2e``.
> > > > > > +
> > > > >
> > > > > Libvirt doesn't have any special handling for this machine so this
> > > > > shouldn't impact us.
> > > > >
> > > >
> > > > Well, Peter,
> > > >
> > > > I was also wondering libvirt listed as a recipient, and I think it
> > > > creates unneeded noise in your group, but Philippe uses some his
> > > > system for automatic picking of recipients, and libivrt somehow
> > > > appears there during that process. Philippe, either correct that
> > > > detail in this particular component of your workflow, or change
> > > > entirely your system for recipient choice - the current workflow
> > > > creates incredible amount of noise, wasting time of many people.
> > >
> > > Note that my message above was not a criticism of why we've got it but
> > > more of a review. This review though it just that removing this is okay
> > > and no action needs to be taken. Unfortunately I'm usually not familiar
> > > enough with qemu to do a full review.
> > >
> > > >
> > > > This happened before in case of deprecating an ancient mips machine,
> > > > that absolutely  doesn't have anything to do with linvirt.
> > >
> > > In some cases it might seem like that. Specifically for things where
> > > libvirt isn't impacted such as machine type change because we try to
> > > stay machine type agnostic or for something that we don't use.
> > >
> > > On the other hand there were plenty cases where we were impacted and
> > > where we do want to know about these deprecations. It's in fact the
> > > primary reason why this was established after an agreement between qemu
> > > and libvirt projects and in fact I was one of those who argued for
> > > adding such a thing.
> > >
> > > As I was one of the proponents I feel obliged to always respond to these
> > > notifications as we've more than once encountered something that in the
> > > end impacted libvirt.
> > >
> 
> But, Peter Krempa,
> 
> I see libvirt-dev listed as a recipient for a patch (from this series)
> that changes an e-mail of a colleague of mine. Why would be

Currently the tooling creates a union of recipients based on the set of
files changed by the patchset and then sends the whole series to
everybody.

That is to ensure that the recipient has the full context.

> libvirt-dev be interested in that? Is libvirt really so sensitive to
> the degree that to be afraid that changing an e-mail of a QEMU
> contributor would impact libvirt design and/or its interface towards

No, we don't care about that. We care about changes to the
'docs/system/deprecated.rst'. In this very specific instance we usually
don't even care about the context of the other patches and can look them
up manually if necessary.

The problem is that the tooling currently doesn't really allow this
usage. The next best thing is to send more emails rather than forget to
send the notification.

> QEMU? If you wishes that to remain so, I am of course fine with it,
> who am I to determine that, but it looks like a severe overkill to me.

Feel free to fix the git-publish tool. IMO asking
maintainers/contributors to just CC patches which change
'docs/system/deprecated.rst' to libvirt-list would create too
complicated rules and is in general not worth doing. Just if we can do
it programatically.

If this ever becomes a problem for libvir-list I'm sure that we'll drop
ourselves from the CC if we reach such consensus.

Please don't question this approach any more if you don't plan to fix
the tooling.
diff mbox series

Patch

diff --git a/docs/system/deprecated.rst b/docs/system/deprecated.rst
index 3142fac386..f0061f94aa 100644
--- a/docs/system/deprecated.rst
+++ b/docs/system/deprecated.rst
@@ -368,6 +368,11 @@  mips ``r4k`` platform (since 5.0)
 This machine type is very old and unmaintained. Users should use the ``malta``
 machine type instead.
 
+mips ``fulong2e`` machine (since 5.1)
+'''''''''''''''''''''''''''''''''''''
+
+This machine has been renamed ``fuloong2e``.
+
 ``pc-1.0``, ``pc-1.1``, ``pc-1.2`` and ``pc-1.3`` (since 5.0)
 '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
diff --git a/docs/system/target-mips.rst b/docs/system/target-mips.rst
index 2736fd0509..cd2a931edf 100644
--- a/docs/system/target-mips.rst
+++ b/docs/system/target-mips.rst
@@ -74,7 +74,7 @@  The MIPS Magnum R4000 emulation supports:
 
 -  G364 framebuffer
 
-The Fulong 2E emulation supports:
+The Fuloong 2E emulation supports:
 
 -  Loongson 2E CPU
 
diff --git a/default-configs/mips64el-softmmu.mak b/default-configs/mips64el-softmmu.mak
index 8b0c9b1e15..9f8a3ef156 100644
--- a/default-configs/mips64el-softmmu.mak
+++ b/default-configs/mips64el-softmmu.mak
@@ -2,7 +2,7 @@ 
 
 include mips-softmmu-common.mak
 CONFIG_IDE_VIA=y
-CONFIG_FULONG=y
+CONFIG_FULOONG=y
 CONFIG_ATI_VGA=y
 CONFIG_RTL8139_PCI=y
 CONFIG_JAZZ=y
diff --git a/hw/isa/vt82c686.c b/hw/isa/vt82c686.c
index d9b51fce8d..fac4e56b7d 100644
--- a/hw/isa/vt82c686.c
+++ b/hw/isa/vt82c686.c
@@ -503,7 +503,7 @@  static void via_class_init(ObjectClass *klass, void *data)
     dc->vmsd = &vmstate_via;
     /*
      * Reason: part of VIA VT82C686 southbridge, needs to be wired up,
-     * e.g. by mips_fulong2e_init()
+     * e.g. by mips_fuloong2e_init()
      */
     dc->user_creatable = false;
 }
diff --git a/hw/pci-host/bonito.c b/hw/pci-host/bonito.c
index d0201ce59e..f9697dcc43 100644
--- a/hw/pci-host/bonito.c
+++ b/hw/pci-host/bonito.c
@@ -11,7 +11,7 @@ 
  */
 
 /*
- * fulong 2e mini pc has a bonito north bridge.
+ * fuloong 2e mini pc has a bonito north bridge.
  */
 
 /*
@@ -573,11 +573,11 @@  static int pci_bonito_map_irq(PCIDevice *pci_dev, int irq_num)
     slot = (pci_dev->devfn >> 3);
 
     switch (slot) {
-    case 5:   /* FULONG2E_VIA_SLOT, SouthBridge, IDE, USB, ACPI, AC97, MC97 */
+    case 5:   /* FULOONG2E_VIA_SLOT, SouthBridge, IDE, USB, ACPI, AC97, MC97 */
         return irq_num % 4 + BONITO_IRQ_BASE;
-    case 6:   /* FULONG2E_ATI_SLOT, VGA */
+    case 6:   /* FULOONG2E_ATI_SLOT, VGA */
         return 4 + BONITO_IRQ_BASE;
-    case 7:   /* FULONG2E_RTL_SLOT, RTL8139 */
+    case 7:   /* FULOONG2E_RTL_SLOT, RTL8139 */
         return 5 + BONITO_IRQ_BASE;
     case 8 ... 12: /* PCI slot 1 to 4 */
         return (slot - 8 + irq_num) + 6 + BONITO_IRQ_BASE;
diff --git a/tests/qtest/endianness-test.c b/tests/qtest/endianness-test.c
index 2798802c63..cc088ac01a 100644
--- a/tests/qtest/endianness-test.c
+++ b/tests/qtest/endianness-test.c
@@ -33,7 +33,7 @@  static const TestCase test_cases[] = {
     { "mips64", "pica61", 0x90000000, .bswap = true },
     { "mips64", "mips", 0x14000000, .bswap = true },
     { "mips64", "malta", 0x10000000, .bswap = true },
-    { "mips64el", "fulong2e", 0x1fd00000 },
+    { "mips64el", "fuloong2e", 0x1fd00000 },
     { "ppc", "g3beige", 0xfe000000, .bswap = true, .superio = "i82378" },
     { "ppc", "40p", 0x80000000, .bswap = true },
     { "ppc", "bamboo", 0xe8000000, .bswap = true, .superio = "i82378" },
diff --git a/MAINTAINERS b/MAINTAINERS
index 8f597aae12..8136a0e56c 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -1081,13 +1081,13 @@  R: Aleksandar Rikalo <aleksandar.rikalo@rt-rk.com>
 S: Obsolete
 F: hw/mips/mips_r4k.c
 
-Fulong 2E
+Fuloong 2E
 M: Huacai Chen <chenhc@lemote.com>
 M: Philippe Mathieu-Daudé <f4bug@amsat.org>
 M: Aleksandar Markovic <aleksandar.qemu.devel@gmail.com>
 R: Jiaxun Yang <jiaxun.yang@flygoat.com>
 S: Odd Fixes
-F: hw/mips/mips_fulong2e.c
+F: hw/mips/fuloong2e.c
 F: hw/isa/vt82c686.c
 F: hw/pci-host/bonito.c
 F: include/hw/isa/vt82c686.h
diff --git a/hw/mips/Kconfig b/hw/mips/Kconfig
index 2240504dff..67d39c56a4 100644
--- a/hw/mips/Kconfig
+++ b/hw/mips/Kconfig
@@ -41,7 +41,7 @@  config JAZZ
     select DS1225Y
     select JAZZ_LED
 
-config FULONG
+config FULOONG
     bool
     select PCI_BONITO
 
diff --git a/hw/mips/Makefile.objs b/hw/mips/Makefile.objs
index 525809af07..8ab41edc3f 100644
--- a/hw/mips/Makefile.objs
+++ b/hw/mips/Makefile.objs
@@ -3,6 +3,6 @@  obj-$(CONFIG_R4K) += mips_r4k.o
 obj-$(CONFIG_MALTA) += gt64xxx_pci.o mips_malta.o
 obj-$(CONFIG_MIPSSIM) += mips_mipssim.o
 obj-$(CONFIG_JAZZ) += mips_jazz.o
-obj-$(CONFIG_FULONG) += mips_fulong2e.o
+obj-$(CONFIG_FULOONG) += fuloong2e.o
 obj-$(CONFIG_MIPS_CPS) += cps.o
 obj-$(CONFIG_MIPS_BOSTON) += boston.o
diff --git a/hw/mips/mips_fulong2e.c b/hw/mips/fuloong2e.c
similarity index 91%
rename from hw/mips/mips_fulong2e.c
rename to hw/mips/fuloong2e.c
index 6996f5e3d1..f583c44b79 100644
--- a/hw/mips/mips_fulong2e.c
+++ b/hw/mips/fuloong2e.c
@@ -1,5 +1,5 @@ 
 /*
  * QEMU fulong 2e mini pc support
  *
  * Copyright (c) 2008 yajin (yajin@vm-kernel.org)
  * Copyright (c) 2009 chenming (chenming@rdc.faw.com.cn)
@@ -11,8 +11,8 @@ 
  */
 
 /*
  * Fulong 2e mini pc is based on ICT/ST Loongson 2e CPU (MIPS III like, 800MHz)
  * http://www.linux-mips.org/wiki/Fulong
  *
  * Loongson 2e user manual:
  * http://www.loongsondeveloper.com/doc/Loongson2EUserGuide.pdf
@@ -45,13 +45,13 @@ 
 #include "sysemu/reset.h"
 #include "qemu/error-report.h"
 
-#define DEBUG_FULONG2E_INIT
+#define DEBUG_FULOONG2E_INIT
 
 #define ENVP_ADDR               0x80002000l
 #define ENVP_NB_ENTRIES         16
 #define ENVP_ENTRY_SIZE         256
 
 /* fulong 2e has a 512k flash: Winbond W39L040AP70Z */
 #define BIOS_SIZE               (512 * KiB)
 #define MAX_IDE_BUS             2
 
@@ -68,12 +68,12 @@ 
  * 2, use "Bonito2edev" to replace "dir_corresponding_to_your_target_hardware"
  * in the "Compile Guide".
  */
-#define FULONG_BIOSNAME "pmon_fulong2e.bin"
+#define FULOONG_BIOSNAME "pmon_2e.bin"
 
 /* PCI SLOT in fulong 2e */
 #define FULONG2E_VIA_SLOT        5
 #define FULONG2E_ATI_SLOT        6
 #define FULONG2E_RTL8139_SLOT    7
 
 static struct _loaderparams {
     int ram_size;
@@ -278,7 +278,7 @@  static void network_init(PCIBus *pci_bus)
         const char *default_devaddr = NULL;
 
         if (i == 0 && (!nd->model || strcmp(nd->model, "rtl8139") == 0)) {
             /* The fulong board has a RTL8139 card using PCI SLOT 7 */
             default_devaddr = "07";
         }
 
@@ -286,7 +286,7 @@  static void network_init(PCIBus *pci_bus)
     }
 }
 
-static void mips_fulong2e_init(MachineState *machine)
+static void mips_fuloong2e_init(MachineState *machine)
 {
     const char *kernel_filename = machine->kernel_filename;
     const char *kernel_cmdline = machine->kernel_cmdline;
@@ -318,7 +318,7 @@  static void mips_fulong2e_init(MachineState *machine)
     memory_region_add_subregion(address_space_mem, 0, machine->ram);
 
     /* Boot ROM */
-    memory_region_init_rom(bios, NULL, "fulong2e.bios", BIOS_SIZE,
+    memory_region_init_rom(bios, NULL, "fuloong2e.bios", BIOS_SIZE,
                            &error_fatal);
     memory_region_add_subregion(address_space_mem, 0x1fc00000LL, bios);
 
@@ -336,7 +336,7 @@  static void mips_fulong2e_init(MachineState *machine)
         write_bootloader(env, memory_region_get_ram_ptr(bios), kernel_entry);
     } else {
         if (bios_name == NULL) {
-                bios_name = FULONG_BIOSNAME;
+                bios_name = FULOONG_BIOSNAME;
         }
         filename = qemu_find_file(QEMU_FILE_TYPE_BIOS, bios_name);
         if (filename) {
@@ -362,7 +362,7 @@  static void mips_fulong2e_init(MachineState *machine)
     pci_bus = bonito_init((qemu_irq *)&(env->irq[2]));
 
     /* South bridge -> IP5 */
-    vt82c686b_southbridge_init(pci_bus, FULONG2E_VIA_SLOT, env->irq[5],
+    vt82c686b_southbridge_init(pci_bus, FULOONG2E_VIA_SLOT, env->irq[5],
                                &smbus, &isa_bus);
 
     /* GPU */
@@ -383,14 +383,15 @@  static void mips_fulong2e_init(MachineState *machine)
     network_init(pci_bus);
 }
 
-static void mips_fulong2e_machine_init(MachineClass *mc)
+static void mips_fuloong2e_machine_init(MachineClass *mc)
 {
-    mc->desc = "Fulong 2e mini pc";
-    mc->init = mips_fulong2e_init;
+    mc->desc = "Fuloong 2e mini pc";
+    mc->alias = "fulong2e";             /* Incorrect name used up to QEMU 4.2 */
+    mc->init = mips_fuloong2e_init;
     mc->block_default_type = IF_IDE;
     mc->default_cpu_type = MIPS_CPU_TYPE_NAME("Loongson-2E");
     mc->default_ram_size = 256 * MiB;
-    mc->default_ram_id = "fulong2e.ram";
+    mc->default_ram_id = "fuloong2e.ram";
 }
 
-DEFINE_MACHINE("fulong2e", mips_fulong2e_machine_init)
+DEFINE_MACHINE("fuloong2e", mips_fuloong2e_machine_init)
@@ -1,5 +1,5 @@ 
 /*
- * QEMU fulong 2e mini pc support
+ * QEMU fuloong 2e mini pc support
  *
  * Copyright (c) 2008 yajin (yajin@vm-kernel.org)
@@ -11,8 +11,8 @@ 
 
 /*
- * Fulong 2e mini pc is based on ICT/ST Loongson 2e CPU (MIPS III like, 800MHz)
- * http://www.linux-mips.org/wiki/Fulong
+ * Fuloong 2e mini pc is based on ICT/ST Loongson 2e CPU (MIPS III like, 800MHz)
+ * https://www.linux-mips.org/wiki/Fuloong_2E
  *
  * Loongson 2e user manual:
@@ -45,13 +45,13 @@ 
 #define ENVP_ENTRY_SIZE         256
 
-/* fulong 2e has a 512k flash: Winbond W39L040AP70Z */
+/* Fuloong 2e has a 512k flash: Winbond W39L040AP70Z */
 #define BIOS_SIZE               (512 * KiB)
 #define MAX_IDE_BUS             2
@@ -68,12 +68,12 @@ 
 
-/* PCI SLOT in fulong 2e */
-#define FULONG2E_VIA_SLOT        5
-#define FULONG2E_ATI_SLOT        6
-#define FULONG2E_RTL8139_SLOT    7
+/* PCI SLOT in Fuloong 2e */
+#define FULOONG2E_VIA_SLOT        5
+#define FULOONG2E_ATI_SLOT        6
+#define FULOONG2E_RTL8139_SLOT    7
 
 static struct _loaderparams {
@@ -278,7 +278,7 @@  static void network_init(PCIBus *pci_bus)
 
         if (i == 0 && (!nd->model || strcmp(nd->model, "rtl8139") == 0)) {
-            /* The fulong board has a RTL8139 card using PCI SLOT 7 */
+            /* The Fuloong board has a RTL8139 card using PCI SLOT 7 */
             default_devaddr = "07";
         }